@@ -130,7 +130,7 @@ void LineFillStyle::read( istream& figfile, int& sub_type, int& depth, bool join
         linejoin = 0;
 
     keep_range( line_style,     "line_style",      -1, 5 );
-    keep_range( line_thickness, "line_thickness", 0 );
+    keep_range( line_thickness, "line_thickness", 0.0f );
     keep_range( pen_color,      "pen_color",       -1, 543 );
     keep_range( fill_color,     "fill_color",      -1, 543 );
     // pen style is unused, so ignore its value
