@@ -36,8 +36,8 @@ istream& Ellipse::read( istream& figfile )
     // direction should be always 1, but apparently it is sometimes 0;
     // don't complain as it is not used anyhow
     //keep_range( direction, "ellipse direction", 1, 1 );
-    keep_range( radius_x,  "ellipse radius_x",  0 );
-    keep_range( radius_y,  "ellipse radius_y",  0 );
+    keep_range( radius_x,  "ellipse radius_x",  0.0f );
+    keep_range( radius_y,  "ellipse radius_y",  0.0f );
 
     lfs = linefillstyles.insert( lfstmp ).first;
     lfs->stylename();
