@@ -240,9 +240,19 @@ ostream& Spline::write( ostream& out )
     }
     if( sub_type == 0 )
         d << "L " << tr_p(lineto2-m);
+
+    if( d.str().size() >= 1<<16 ) {
+	static bool warn_long = false;
+	if( !warn_long ) {
+	    cerr << "Warning: some splines might be too large for OpenOffice.org."
+		 << endl;
+	    warn_long = true;
+	}
+    }
+
     // fill it, if necessary
     if( sub_type % 2 == 0 ) {
-        string line_d = d.str();
+        const string line_d = d.str();
         if( lfs->hasFill() ) {
             d << " Z";
             path["draw:style-name"] << lfs->stylename_fill();
